bayespy.inference.vmp.nodes.node.Node.plates_multiplier
=======================================================

.. currentmodule:: bayespy.inference.vmp.nodes.node

.. autoattribute:: Node.plates_multiplier